<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @package Calibration
 * @since 1.0.0
 * @version 1.0.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) :
	return;
endif;
?>

<div id="comments" class="comments-area">

	<?php
	if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
			$comments_number = get_comments_number();
			if ( '1' === $comments_number ) :
				/* translators: %s: post title */
				printf( _x( 'One thought on: %s', 'comments title', 'calibration' ), '<span>' . get_the_title() . '</span>' );
			else :
				/* translators: 1: number of comments, 2: post title */
				printf(
					_nx(
						'%1$s thought on: %2$s',
						'%1$s thoughts on: %2$s',
						$comments_number,
						'comments title',
						'calibration'
					),
					number_format_i18n( $comments_number ),
					'<span>' . get_the_title() . '</span>'
				);
			endif;
			?>
		</h2>

		<ol class="comment-list">
			<?php
				wp_list_comments( array(
					'avatar_size' => 100,
					'style'       => 'ol',
					'short_ping'  => true
				) );
			?>
		</ol>

		<?php the_comments_pagination( array(
			'prev_text' => __( 'Previous', 'calibration' ),
			'next_text' => __( 'Next', 'calibration' ),
		) );

	endif;

	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<p class="no-comments"><?php _e( 'Comments are closed.', 'calibration' ); ?></p>
	<?php
	endif;

	comment_form();
	?>

</div><!-- #comments -->
