<?php
/**
 * Hooks and functions for handling styles and scripts within this theme
 *
 * @package Calibration
 * @since 1.0.0
 * @version 1.0.0
 */

add_filter( 'wp_resource_hints', 'calibration_resource_hints', 10, 2 );
/**
 * Add preconnect for Google Fonts.
 *
 * Filter hook: 'wp_resource_hints'
 *
 * @since Calibration 1.0.0
 *
 * @param array  $urls           URLs to print for resource hints.
 * @param string $relation_type  The relation type the URLs are printed.
 * @return array $urls           URLs to print for resource hints.
 */
function calibration_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'calibration-fonts', 'queue' ) && 'preconnect' === $relation_type ) :
		$urls[] = array(
			'href' => 'https://fonts.googleapis.com',
			'crossorigin',
		);
	endif;

	return $urls;
}

add_action( 'wp_enqueue_scripts', 'calibration_enqueue_styles', 4 );
/**
 * Enqueue theme styles
 *
 * Action hook: 'wp_enqueue_scripts'
 *
 * @since 1.0.0
 */
function calibration_enqueue_styles() {
	wp_enqueue_style( 'calibration-fonts', 'https://fonts.googleapis.com/css?family=Montserrat:300,300i,400,400i,600|Droid+Serif:400,400i,700', false, calibration_ver() );
	wp_enqueue_style( 'calibration-style', get_stylesheet_uri(), false, calibration_ver() );
}

add_action( 'wp_enqueue_scripts', 'calibration_enqueue_modernizr', 9 );
/**
 * Enqueue modernizr early
 *
 * Action hook: 'wp_enqueue_scripts'
 *
 * @since 1.0.0
 */
function calibration_enqueue_modernizr() {
	wp_enqueue_script( 'modernizr', CALIB_JS_URI . 'libs/' . 'modernizr.js', false, calibration_ver(), false );
}

add_action( 'wp_enqueue_scripts', 'calibration_enqueue_scripts', 11 );
/**
 * Enqueue theme scripts
 *
 * Action hook: 'wp_enqueue_scripts'
 *
 * @since 1.0.0
 */
function calibration_enqueue_scripts() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) :
		wp_enqueue_script( 'comment-reply' );
	endif;

	wp_enqueue_script( 'imagesloaded' );
	wp_enqueue_script( 'headroom', CALIB_JS_URI . 'libs/' . 'headroom.min.js', false, '0.9.3', true );
	wp_enqueue_script( 'magnific-popup', CALIB_JS_URI . 'libs/' . 'jquery.magnific-popup.min.js', array( 'jquery' ), '1.1.0', true );
	wp_enqueue_script( 'packery', CALIB_JS_URI . 'libs/' . 'packery.pkgd.min.js', array( 'jquery' ), '2.1.1', true );
	wp_enqueue_script( 'jquery-customselect', CALIB_JS_URI . 'libs/' . 'jquery.customSelect.min.js', array( 'jquery' ), '0.5.1', true );
	if ( calibration_has_header_image() || get_background_image() ) :
		wp_enqueue_script( 'background-check', CALIB_JS_URI . 'libs/' . 'background-check.min.js', false, '1.2.2', true );
		wp_add_inline_script( 'background-check', "
			jQuery(window).on('load', function() {
				return BackgroundCheck.init({
					targets: 'body, #header',
					images: '.custom-background, .wp-custom-header',
					threshold: 35,
					windowEvents: false
				});
			});"
		);
	endif;

	wp_enqueue_script( 'calibration-script', CALIB_JS_URI . 'script.js', array( 'jquery' ), calibration_ver(), true );
}
